import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Random;

public class InteractiveChristmasScene extends JPanel implements ActionListener {
    private Color treeColor = Color.GREEN;
    private Color ornamentColor = Color.RED;
    private boolean showSnowman = true;
    private boolean showSanta = true;
    private int treeSize = 1;
    private int snowmanSize = 1;
    private int santaSize = 1;
    private final int[] snowY = new int[50];
    private final int[] snowX = new int[50];
    private final Random random = new Random();

    public InteractiveChristmasScene() {
        Timer timer = new Timer(50, this);
        timer.start();

        // Δημιουργία αρχικών θέσεων χιονονιφάδων
        for (int i = 0; i < snowY.length; i++) {
            snowX[i] = random.nextInt(600);
            snowY[i] = random.nextInt(800);
        }
    }

    public static void main(String[] args) {
        JFrame frame = new JFrame("Διαδραστική Χριστουγεννιάτικη Σκηνή");
        InteractiveChristmasScene panel = new InteractiveChristmasScene();

        frame.add(panel);
        frame.setSize(600, 800);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setVisible(true);

        JPanel buttonPanel = new JPanel();
        JButton changeTreeColor = new JButton("Αλλαγή Χρώματος Δέντρου");
        JButton changeOrnaments = new JButton("Αλλαγή Χρώματος Στολιδιών");
        JButton toggleSnowman = new JButton("Εναλλαγή Χιονάνθρωπου");
        JButton toggleSanta = new JButton("Εναλλαγή Άη Βασίλη");
        JButton increaseTreeSize = new JButton("Μεγέθυνση Δέντρου");
        JButton decreaseTreeSize = new JButton("Σμίκρυνση Δέντρου");

        changeTreeColor.addActionListener(e -> {
            panel.treeColor = JColorChooser.showDialog(frame, "Επιλέξτε χρώμα δέντρου", panel.treeColor);
            panel.repaint();
        });

        changeOrnaments.addActionListener(e -> {
            panel.ornamentColor = JColorChooser.showDialog(frame, "Επιλέξτε χρώμα στολιδιών", panel.ornamentColor);
            panel.repaint();
        });

        toggleSnowman.addActionListener(e -> {
            panel.showSnowman = !panel.showSnowman;
            panel.repaint();
        });

        toggleSanta.addActionListener(e -> {
            panel.showSanta = !panel.showSanta;
            panel.repaint();
        });

        increaseTreeSize.addActionListener(e -> {
            panel.treeSize++;
            panel.repaint();
        });

        decreaseTreeSize.addActionListener(e -> {
            if (panel.treeSize > 1) {
                panel.treeSize--;
                panel.repaint();
            }
        });

        buttonPanel.add(changeTreeColor);
        buttonPanel.add(changeOrnaments);
        buttonPanel.add(toggleSnowman);
        buttonPanel.add(toggleSanta);
        buttonPanel.add(increaseTreeSize);
        buttonPanel.add(decreaseTreeSize);

        frame.add(buttonPanel, BorderLayout.SOUTH);
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);

        setBackground(Color.BLACK);

        // Σχεδίαση χιονονιφάδων
        g.setColor(Color.WHITE);
        for (int i = 0; i < snowY.length; i++) {
            g.fillOval(snowX[i], snowY[i], 5, 5);
        }

        // Σχεδίαση δέντρου
        g.setColor(treeColor);
        for (int i = 0; i < 3; i++) {
            int xCenter = 300;
            int yTop = 100 + i * 100 * treeSize;
            int xLeft = xCenter - 50 * treeSize - i * 20 * treeSize;
            int xRight = xCenter + 50 * treeSize + i * 20 * treeSize;
            int yBottom = yTop + 100 * treeSize;
            g.fillPolygon(new int[]{xCenter, xLeft, xRight}, new int[]{yTop, yBottom, yBottom}, 3);
        }

        // Στολίδια δέντρου
        g.setColor(ornamentColor);
        g.fillOval(280, 180, 20 * treeSize, 20 * treeSize);
        g.fillOval(320, 240, 20 * treeSize, 20 * treeSize);
        g.fillOval(250, 350, 20 * treeSize, 20 * treeSize);

        // Κορμός δέντρου
        g.setColor(new Color(139, 69, 19));
        g.fillRect(290, 400 + (treeSize - 1) * 100, 20 * treeSize, 50 * treeSize);

        // Χιονάνθρωπος
        if (showSnowman) {
            g.setColor(Color.WHITE);
            g.fillOval(100, 500, 80 * snowmanSize, 80 * snowmanSize);
            g.fillOval(85, 580, 110 * snowmanSize, 110 * snowmanSize);
            g.setColor(Color.BLACK);
            g.fillOval(120, 520, 10, 10);
            g.fillOval(150, 520, 10, 10);
            g.fillOval(135, 540, 10, 10);
        }

        // Άη Βασίλης
        if (showSanta) {
            g.setColor(Color.RED);
            g.fillOval(450, 500, 80 * santaSize, 120 * santaSize);
            g.setColor(Color.PINK);
            g.fillOval(470, 460, 40 * santaSize, 40 * santaSize);
        }
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // Κίνηση χιονονιφάδων
        for (int i = 0; i < snowY.length; i++) {
            snowY[i] += 5;
            if (snowY[i] > 800) {
                snowY[i] = 0;
                snowX[i] = random.nextInt(600);
            }
        }
        repaint();
    }
}
